%global _default_patch_fuzz 2

Name:		siril
Version:	1.0.0
Release:	%mkrel 1
Summary:	Astronomical image (pre-)processing program
Group:		Sciences/Astronomy
License:	GPLv3+
URL:		http://free-astro.org/index.php/Siril
Source0:	https://free-astro.org/download/%{name}-%{version}.tar.bz2
#squidf: fix opencv test version for MGA 
Patch0:     siril-1.0.0-fix-opencv-version.patch
BuildRequires:	appstream-util
#squidf: log complains about it otherwise
BuildRequires:  cmake
BuildRequires:	meson
BuildRequires:	gettext
BuildRequires:	git-core
BuildRequires:	intltool
BuildRequires:	pkgconfig(cfitsio)
BuildRequires:	pkgconfig(exiv2)
BuildRequires:	pkgconfig(ffms2)
BuildRequires:	pkgconfig(fftw3)
BuildRequires:	pkgconfig(gsl)
BuildRequires:	pkgconfig(gtk+-3.0)
#squidf: added based on Gitlab doc
BuildRequires:  pkgconfig(gtkextra-3.0)
BuildRequires:	pkgconfig(json-glib-1.0)
BuildRequires:	pkgconfig(libavcodec)
BuildRequires:	pkgconfig(libavformat)
BuildRequires:	pkgconfig(libavutil)
BuildRequires:	pkgconfig(libconfig)
#squidf: useless for Linux according to Gitlab doc 
#BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(libheif)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(libraw)
BuildRequires:	pkgconfig(libswresample)
BuildRequires:	pkgconfig(libswscale)
BuildRequires:	pkgconfig(libtiff-4)
BuildRequires:	pkgconfig(opencv)
BuildRequires:	pkgconfig(rtprocess)
BuildRequires:	pkgconfig(wcslib)

Recommends:	gnuplot

%description
Siril is an image processing tool specially tailored for noise reduction and
improving the signal/noise ratio of an image from multiple captures, as
required in astronomy. Siril can align automatically or manually, stack and
enhance pictures from various file formats, even images sequences (movies and
SER files).

%prep
%setup -q -c %{name}
%patch0 -p1 -b .fix-opencv-version

%build
# override build directory, the default "build" is a regular source directory
%define _vpath_builddir builddir

%meson
%meson_build

%install
%meson_install

%find_lang %{name}

mkdir -p %{buildroot}%{_iconsdir}/hicolor/scalable/apps
install -m 0644 pixmaps/siril.svg %{buildroot}%{_iconsdir}/hicolor/scalable/apps/siril.svg

%check
appstream-util validate-relax --nonet %{buildroot}%{_metainfodir}/org.free_astro.%{name}.appdata.xml

%files -f %{name}.lang
%doc AUTHORS NEWS README.md
#squidf: license complement
%license LICENSE.md LICENSE_sleef.txt
%{_bindir}/%{name}
%{_bindir}/%{name}-cli
%{_datadir}/%{name}/
%{_datadir}/applications/org.free_astro.%{name}.desktop
%{_datadir}/mime/packages/%{name}.xml
%{_metainfodir}/org.free_astro.%{name}.appdata.xml
%{_iconsdir}/hicolor/scalable/apps/%{name}.svg
%{_iconsdir}/hicolor/scalable/mimetypes/*.svg
%{_iconsdir}/hicolor/symbolic/apps/org.free_astro.%{name}-symbolic.svg
%{_iconsdir}/hicolor/*/apps/org.free_astro.%{name}.svg
%{_mandir}/man1/%{name}.1*
%{_mandir}/man1/%{name}-cli.1*
#squidf: licenses are packaged with %%license
%exclude %{_docdir}/%{name}/LICENSE.md
%exclude %{_docdir}/%{name}/LICENSE_sleef.txt


%changelog
* Fri Mar 11 2022 squidf <squidf> 1.0.0-1.mga8
+ Revision: 1790461
- First stable version
  Update to 1.0.0
  Handle LICENSE_sleef.txt location
  Remove curl build dependency
  Add cmake and gtkextra-3.0 build dependencies
  Add opencv test patch to fix build

* Fri Oct 30 2020 joequant <joequant> 0.99.6-3.mga8
+ Revision: 1640715
- rebuild with opencv

* Fri Oct 23 2020 daviddavid <daviddavid> 0.99.6-2.mga8
+ Revision: 1638687
- switch to meson build system

* Fri Oct 23 2020 daviddavid <daviddavid> 0.99.6-1.mga8
+ Revision: 1638681
- new version: 0.99.6

* Wed Sep 09 2020 zezinho <zezinho> 0.99.4-2.mga8
+ Revision: 1623895
- rebuild against libraw20

* Tue Aug 18 2020 daviddavid <daviddavid> 0.99.4-1.mga8
+ Revision: 1614721
- new version: 0.99.4
- remove merged upstream patch
- enable exiv2, libheif and rtprocess support

* Thu Jul 23 2020 daviddavid <daviddavid> 0.9.12-6.mga8
+ Revision: 1608164
- rebuild for new cfitsio 3.480

* Tue Jun 02 2020 daviddavid <daviddavid> 0.9.12-5.mga8
+ Revision: 1589683
- add upstream patch to fix build with gcc 10

* Fri Mar 27 2020 daviddavid <daviddavid> 0.9.12-4.mga8
+ Revision: 1560894
- rebuild for new cfitsio 3.470

* Wed Feb 19 2020 umeabot <umeabot> 0.9.12-3.mga8
+ Revision: 1544335
- Mageia 8 Mass Rebuild

* Sat Jan 25 2020 daviddavid <daviddavid> 0.9.12-2.mga8
+ Revision: 1482894
- rebuild for new opencv 4.2.0
+ wally <wally>
- replace deprecated %%configure2_5x

* Mon Nov 04 2019 daviddavid <daviddavid> 0.9.12-1.mga8
+ Revision: 1457576
- new version: 0.9.12

* Tue Aug 27 2019 daviddavid <daviddavid> 0.9.11-2.mga8
+ Revision: 1433787
- rebuild for new gsl 2.6

* Sun Jun 30 2019 daviddavid <daviddavid> 0.9.11-1.mga8
+ Revision: 1416309
- new version: 0.9.11

* Fri Jan 18 2019 daviddavid <daviddavid> 0.9.10-1.mga7
+ Revision: 1357855
- new version: 0.9.10

* Thu Sep 06 2018 daviddavid <daviddavid> 0.9.9-2.mga7
+ Revision: 1257571
- add patch to fix build with new glibc
- rebuild for new libraw 0.19.0

* Thu Jun 07 2018 daviddavid <daviddavid> 0.9.9-1.mga7
+ Revision: 1235111
- new version: 0.9.9

* Sun May 13 2018 daviddavid <daviddavid> 0.9.8.3-6.mga7
+ Revision: 1228731
- rebuild for new cfitsio 3.450

* Thu Apr 26 2018 daviddavid <daviddavid> 0.9.8.3-5.mga7
+ Revision: 1222571
- rebuild for new ffmpeg 4.0

* Thu Apr 12 2018 daviddavid <daviddavid> 0.9.8.3-4.mga7
+ Revision: 1217796
- rebuild for new opencv 3.4.1

* Fri Apr 06 2018 kekepower <kekepower> 0.9.8.3-3.mga7
+ Revision: 1215673
- Rebuild for new libconfig

* Tue Feb 20 2018 daviddavid <daviddavid> 0.9.8.3-1.mga7
+ Revision: 1203605
- new version: 0.9.8.3
- remove merged upstream patch

* Wed Jan 31 2018 daviddavid <daviddavid> 0.9.8-1.mga7
+ Revision: 1198295
- new version: 0.9.8

* Sat Dec 23 2017 daviddavid <daviddavid> 0.9.7-2.mga7
+ Revision: 1184169
- rebuild for new gsl

* Sat Oct 07 2017 daviddavid <daviddavid> 0.9.7-1.mga7
+ Revision: 1169994
- new version: 0.9.7
- rename and rediff mga-install patch

* Sat Jul 01 2017 daviddavid <daviddavid> 0.9.6-1.mga6
+ Revision: 1108826
- new version: 0.9.6
- recommends gnuplot

* Tue May 02 2017 akien <akien> 0.9.5-4.mga6
+ Revision: 1098375
- Rebuild for ffmpeg 3.3

* Thu Mar 09 2017 daviddavid <daviddavid> 0.9.5-3.mga6
+ Revision: 1091138
- rebuild for ffmpeg 3.2.4

* Wed Dec 28 2016 neoclust <neoclust> 0.9.5-2.mga6
+ Revision: 1078460
- Rebuild for new libraw

* Tue Nov 29 2016 daviddavid <daviddavid> 0.9.5-1.mga6
+ Revision: 1070993
- fix release tag
- new version: 0.9.5
- rename and rediff mga-install patch

* Tue Nov 22 2016 eatdirt <eatdirt> 0.9.4-4.mga6
+ Revision: 1068813
- Rebuild for new cfitsio

* Thu Sep 15 2016 daviddavid <daviddavid> 0.9.4-3.mga6
+ Revision: 1052979
- use a new set of icons (thanks to the developer lock042)

* Sun Sep 11 2016 daviddavid <daviddavid> 0.9.4-2.mga6
+ Revision: 1051440
- update desktop file categories from upstream

* Fri Sep 09 2016 daviddavid <daviddavid> 0.9.4-1.mga6
+ Revision: 1051048
- initial package siril

